from albanian_tools import AlbanianTools

albanian_tools = AlbanianTools()

if __name__ == '__main__':
    print(albanian_tools.integer_to_albanian_text_converter(217))
    print(albanian_tools.integer_to_albanian_text_converter(451))
    print(albanian_tools.integer_to_albanian_text_converter(19))
    print(albanian_tools.integer_to_albanian_text_converter(717))
    print(albanian_tools.integer_to_albanian_text_converter(888))

